==> kazehakase-0.5.2.tar.gz: kazehakase-0.5.2/src/kz-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __KZ_ENUM_TYPES_H__
#define __KZ_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "kz-app.h" */
GType kz_ui_level_get_type (void);
#define KZ_TYPE_UI_LEVEL (kz_ui_level_get_type())
/* enumerations from "kz-embed.h" */
GType kz_embed_load_flag_get_type (void);
#define KZ_TYPE_EMBED_LOAD_FLAG (kz_embed_load_flag_get_type())
GType kz_embed_reload_flag_get_type (void);
#define KZ_TYPE_EMBED_RELOAD_FLAG (kz_embed_reload_flag_get_type())
GType kz_embed_go_action_get_type (void);
#define KZ_TYPE_EMBED_GO_ACTION (kz_embed_go_action_get_type())
GType kz_embed_nav_link_get_type (void);
#define KZ_TYPE_EMBED_NAV_LINK (kz_embed_nav_link_get_type())
GType kz_embed_copy_type_get_type (void);
#define KZ_TYPE_EMBED_COPY_TYPE (kz_embed_copy_type_get_type())
/* enumerations from "kz-embed-event.h" */
GType kz_embed_event_key_modifier_get_type (void);
#define KZ_TYPE_EMBED_EVENT_KEY_MODIFIER (kz_embed_event_key_modifier_get_type())
GType kz_embed_event_context_get_type (void);
#define KZ_TYPE_EMBED_EVENT_CONTEXT (kz_embed_event_context_get_type())
GType kz_embed_event_type_get_type (void);
#define KZ_TYPE_EMBED_EVENT_TYPE (kz_embed_event_type_get_type())
/* enumerations from "kz-tab-label.h" */
GType kz_tab_label_state_get_type (void);
#define KZ_TYPE_TAB_LABEL_STATE (kz_tab_label_state_get_type())
/* enumerations from "kz-prefs-win.h" */
GType kz_prefs_win_response_get_type (void);
#define KZ_TYPE_PREFS_WIN_RESPONSE (kz_prefs_win_response_get_type())
/* enumerations from "kz-xml.h" */
GType kz_xml_node_type_get_type (void);
#define KZ_TYPE_XML_NODE_TYPE (kz_xml_node_type_get_type())
/* enumerations from "kz-notebook.h" */
GType kz_notebook_close_condition_get_type (void);
#define KZ_TYPE_NOTEBOOK_CLOSE_CONDITION (kz_notebook_close_condition_get_type())
/* enumerations from "kz-langinfo.h" */
GType language_group_get_type (void);
#define KZ_TYPE_GROUP (language_group_get_type())
/* enumerations from "kz-thumbnails-view.h" */
GType kz_thumbnails_view_mode_get_type (void);
#define KZ_TYPE_THUMBNAILS_VIEW_MODE (kz_thumbnails_view_mode_get_type())
G_END_DECLS

#endif /* __KZ_ENUM_TYPES_H__ */

/* Generated data ends here */

==> kazehakase-0.5.8.tar.gz: kazehakase-0.5.8/src/kz-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __KZ_ENUM_TYPES_H__
#define __KZ_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "kz-app.h" */
GType kz_ui_level_get_type (void);
#define KZ_TYPE_UI_LEVEL (kz_ui_level_get_type())
/* enumerations from "kz-embed.h" */
GType kz_embed_load_flag_get_type (void);
#define KZ_TYPE_EMBED_LOAD_FLAG (kz_embed_load_flag_get_type())
GType kz_embed_reload_flag_get_type (void);
#define KZ_TYPE_EMBED_RELOAD_FLAG (kz_embed_reload_flag_get_type())
GType kz_embed_go_action_get_type (void);
#define KZ_TYPE_EMBED_GO_ACTION (kz_embed_go_action_get_type())
GType kz_embed_nav_link_get_type (void);
#define KZ_TYPE_EMBED_NAV_LINK (kz_embed_nav_link_get_type())
/* enumerations from "kz-embed-event.h" */
GType kz_embed_event_key_modifier_get_type (void);
#define KZ_TYPE_EMBED_EVENT_KEY_MODIFIER (kz_embed_event_key_modifier_get_type())
GType kz_embed_event_context_get_type (void);
#define KZ_TYPE_EMBED_EVENT_CONTEXT (kz_embed_event_context_get_type())
GType kz_embed_event_type_get_type (void);
#define KZ_TYPE_EMBED_EVENT_TYPE (kz_embed_event_type_get_type())
/* enumerations from "kz-tab-label.h" */
GType kz_tab_label_state_get_type (void);
#define KZ_TYPE_TAB_LABEL_STATE (kz_tab_label_state_get_type())
/* enumerations from "kz-prefs-win.h" */
GType kz_prefs_win_response_get_type (void);
#define KZ_TYPE_PREFS_WIN_RESPONSE (kz_prefs_win_response_get_type())
/* enumerations from "kz-xml.h" */
GType kz_xml_node_type_get_type (void);
#define KZ_TYPE_XML_NODE_TYPE (kz_xml_node_type_get_type())
/* enumerations from "kz-notebook.h" */
GType kz_notebook_close_condition_get_type (void);
#define KZ_TYPE_NOTEBOOK_CLOSE_CONDITION (kz_notebook_close_condition_get_type())
/* enumerations from "kz-langinfo.h" */
GType language_group_get_type (void);
#define KZ_TYPE_GROUP (language_group_get_type())
/* enumerations from "kz-thumbnails-view.h" */
GType kz_thumbnails_view_mode_get_type (void);
#define KZ_TYPE_THUMBNAILS_VIEW_MODE (kz_thumbnails_view_mode_get_type())
/* enumerations from "kz-web.h" */
GType kz_web_load_flag_get_type (void);
#define KZ_TYPE_WEB_LOAD_FLAG (kz_web_load_flag_get_type())
GType kz_web_reload_flag_get_type (void);
#define KZ_TYPE_WEB_RELOAD_FLAG (kz_web_reload_flag_get_type())
GType kz_web_go_action_get_type (void);
#define KZ_TYPE_WEB_GO_ACTION (kz_web_go_action_get_type())
GType kz_web_nav_link_get_type (void);
#define KZ_TYPE_WEB_NAV_LINK (kz_web_nav_link_get_type())
G_END_DECLS

#endif /* __KZ_ENUM_TYPES_H__ */

/* Generated data ends here */
